@@ -87,7 +87,9 @@ struct _GeditAppPrivate
 	PeasExtensionSet  *extensions;
 };
 
-G_DEFINE_ABSTRACT_TYPE(GeditApp, gedit_app, G_TYPE_INITIALLY_UNOWNED)
+static GeditApp *app_instance = NULL;
+
+G_DEFINE_ABSTRACT_TYPE(GeditApp, gedit_app, G_TYPE_OBJECT)
 
 static void
 gedit_app_finalize (GObject *object)
@@ -156,20 +158,20 @@ gedit_app_constructor (GType                  gtype,
                        guint                  n_construct_params,
                        GObjectConstructParam *construct_params)
 {
-	static GObject *app = NULL;
-
-	if (!app)
+	if (!app_instance)
 	{
-		app = G_OBJECT_CLASS (gedit_app_parent_class)->constructor (gtype,
-		                                                            n_construct_params,
-		                                                            construct_params);
+		GObject *obj = G_OBJECT_CLASS (
+			gedit_app_parent_class)->constructor (gtype,
+			                                      n_construct_params,
+			                                      construct_params);
 
-		g_object_add_weak_pointer (app, (gpointer *) &app);
+		app_instance = GEDIT_APP (obj);
+		g_object_add_weak_pointer (obj, (gpointer *) &app_instance);
 
-		return app;
+		return obj;
 	}
 
-	return g_object_ref (app);
+	return g_object_ref (app_instance);
 }
 
 static gboolean
@@ -492,7 +494,7 @@ extension_added (PeasExtensionSet *extensions,
 		 PeasExtension    *exten,
 		 GeditApp         *app)
 {
-	peas_extension_call (exten, "activate");
+	gedit_app_activatable_activate (GEDIT_APP_ACTIVATABLE (exten));
 }
 
 static void
@@ -501,7 +503,7 @@ extension_removed (PeasExtensionSet *extensions,
 		   PeasExtension    *exten,
 		   GeditApp         *app)
 {
-	peas_extension_call (exten, "deactivate");
+	gedit_app_activatable_deactivate (GEDIT_APP_ACTIVATABLE (exten));
 }
 
 static void
@@ -533,7 +535,9 @@ gedit_app_init (GeditApp *app)
 			  G_CALLBACK (extension_removed),
 			  app);
 
-	peas_extension_set_call (app->priv->extensions, "activate");
+	peas_extension_set_foreach (app->priv->extensions,
+	                            (PeasExtensionSetForeachFunc) extension_added,
+	                            app);
 }
 
 /**
@@ -547,9 +551,13 @@ gedit_app_init (GeditApp *app)
 GeditApp *
 gedit_app_get_default (void)
 {
-	GeditApp *app;
 	GType type;
 
+	if (app_instance != NULL)
+	{
+		return app_instance;
+	}
+
 #ifdef OS_OSX
 	type = GEDIT_TYPE_APP_OSX;
 #else
@@ -560,18 +568,7 @@ gedit_app_get_default (void)
 #endif
 #endif
 
-	app = GEDIT_APP (g_object_new (type, NULL));
-
-	if (g_object_is_floating (app))
-	{
-		g_object_ref_sink (app);
-	}
-	else
-	{
-		g_object_unref (app);
-	}
-
-	return app;
+	return GEDIT_APP (g_object_new (type, NULL));
 }
 
 static void
@@ -680,8 +677,6 @@ gedit_app_create_window_real (GeditApp    *app,
 {
 	GeditWindow *window;
 
-	gedit_debug (DEBUG_APP);
-
 	/*
 	 * We need to be careful here, there is a race condition:
 	 * when another gedit is launched it checks active_window,
@@ -771,6 +766,8 @@ gedit_app_create_window (GeditApp  *app,
 {
 	GeditWindow *window;
 
+	gedit_debug (DEBUG_APP);
+
 	window = gedit_app_create_window_real (app, TRUE, NULL);
 
 	if (screen != NULL)
@@ -789,6 +786,8 @@ _gedit_app_restore_window (GeditApp    *app,
 {
 	GeditWindow *window;
 
+	gedit_debug (DEBUG_APP);
+
 	window = gedit_app_create_window_real (app, FALSE, role);
 
 	return window;
@@ -902,7 +901,8 @@ is_in_viewport (GeditWindow  *window,
  * equal parts called viewports. This function retrives the #GeditWindow in
  * the given viewport of the given workspace.
  *
- * Return value: the #GeditWindow in the given viewport of the given workspace.
+ * Return value: the #GeditWindow in the given viewport of the given workspace
+ *    or %NULL% if no window is found.
  */
 GeditWindow *
 _gedit_app_get_window_in_viewport (GeditApp  *app,
@@ -934,8 +934,7 @@ _gedit_app_get_window_in_viewport (GeditApp  *app,
 			return window;
 	}
 
-	/* no window on this workspace... create a new one */
-	return gedit_app_create_window (app, screen);
+	return NULL;
 }
 
 /**
