@@ -49,12 +49,11 @@ gedit_get_language_manager (void)
 }
 
 static gint
-language_compare (gconstpointer a, gconstpointer b)
+language_compare (GtkSourceLanguage *a,
+		  GtkSourceLanguage *b)
 {
-	GtkSourceLanguage *lang_a = (GtkSourceLanguage *)a;
-	GtkSourceLanguage *lang_b = (GtkSourceLanguage *)b;
-	const gchar *name_a = gtk_source_language_get_name (lang_a);
-	const gchar *name_b = gtk_source_language_get_name (lang_b);
+	const gchar *name_a = gtk_source_language_get_name (a);
+	const gchar *name_b = gtk_source_language_get_name (b);
 
 	return g_utf8_collate (name_a, name_b);
 }
@@ -75,7 +74,7 @@ gedit_language_manager_list_languages_sorted (GtkSourceLanguageManager *lm,
 		GtkSourceLanguage *lang;
 
 		lang = gtk_source_language_manager_get_language (lm, *ids);
-		g_return_val_if_fail (GTK_IS_SOURCE_LANGUAGE (lang), NULL);
+		g_return_val_if_fail (GTK_SOURCE_IS_LANGUAGE (lang), NULL);
 		++ids;
 
 		if (include_hidden || !gtk_source_language_get_hidden (lang))
@@ -87,4 +86,4 @@ gedit_language_manager_list_languages_sorted (GtkSourceLanguageManager *lm,
 	return g_slist_sort (languages, (GCompareFunc)language_compare);
 }
 
-/* ex:ts=8:noet: */
+/* ex:set ts=8 noet: */
