@@ -299,6 +299,12 @@ class Manager(Gtk.Dialog, Gtk.Buildable):
                 self.build_tree_view()
                 self.build_model()
 
+                # join treeview and toolbar
+                context = self['scrolled_window_snippets'].get_style_context()
+                context.set_junction_sides(Gtk.JunctionSides.BOTTOM)
+                context = self['toolbar'].get_style_context()
+                context.set_junction_sides(Gtk.JunctionSides.TOP)
+
                 source_view = self['source_view_snippet']
                 manager = get_language_manager()
                 lang = manager.get_language('snippets')
@@ -1099,11 +1105,7 @@ class Manager(Gtk.Dialog, Gtk.Buildable):
                 self.select_iter(piter)
 
         def on_entry_drop_targets_drag_data_received(self, entry, context, x, y, selection_data, info, timestamp):
-                if not Gtk.targets_include_uri(context.targets):
-                        return
-
                 uris = drop_get_uris(selection_data)
-
                 if not uris:
                         return
 
